aboutsummaryrefslogtreecommitdiffstats
path: root/modules/desktop/default.nix
diff options
context:
space:
mode:
authorArpit Chakladar <arpitchakladar+git@gmail.com>2026-08-01 19:13:03 +0530
committerArpit Chakladar <arpitchakladar+git@gmail.com>2026-08-01 19:13:03 +0530
commite2272d6299e5c08e4b2cadc42eba673354e4e814 (patch)
treecb9541b0cab8224550e4310c65c20e0164d51d62 /modules/desktop/default.nix
parentd9535cffa21756e37e40eb6b48d56ab37000373c (diff)
downloadhome-manager-config-e2272d6299e5c08e4b2cadc42eba673354e4e814.tar.gz
home-manager-config-e2272d6299e5c08e4b2cadc42eba673354e4e814.zip
feat: using nixpkgs from the local flake registry, added darkman
- Making nixpkgs use the local registry instead of downloading from github from home manager this makes sure that home manager and nixos use the same derivations for any given package - Added darkman and removed gtk for enabling and using dark mode
Diffstat (limited to 'modules/desktop/default.nix')
-rw-r--r--modules/desktop/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/desktop/default.nix b/modules/desktop/default.nix
index 27926ec..15ad896 100644
--- a/modules/desktop/default.nix
+++ b/modules/desktop/default.nix
@@ -1,4 +1,4 @@
# Desktop - Desktop environment configuration (Hyprland, GTK, waybar)
{
lib,
config,
@@ -6,7 +6,7 @@
}:
{
imports = [
- ./gtk
+ ./darkman
./rofi
./xdg
./hyprland
@@ -1,4 +1,4 @@
-# Desktop - Desktop environment configuration (Hyprland, GTK, waybar)
+# Desktop - Desktop environment configuration (Hyprland, darkman, waybar)
{
lib,